@@ -58,8 +58,8 @@ class rdpThread(threading.Thread) :
 			return False
 		#print "rdesktop-cli " + self.parameters + " " + self.host
                 self.ossoc = osso.Context("pyrdesktop", "1.6.0", False)
-                note = osso.SystemNote(osso_c)
-                note.system_note_infoprint("Connecting to '" + self.name + "'")
+                self.note = osso.SystemNote(self.ossoc)
+                self.note.system_note_infoprint("Connecting to '" + self.name + "'")
 		result = os.system("rdesktop-cli " + self.parameters + " " + self.host)
 		needEnter = False
 		#for thread in threading.enumerate():
@@ -223,6 +223,8 @@ class rdesktop:
 		else :
 			#No preferences?  Just make the /apps/rdesktop dir, and everything should work fine
 			self.client.add_dir("/apps/rdesktop", gconf.CLIENT_PRELOAD_NONE)
+                        
+                self.changing_preset = False
 
 		self.about_dialog = None  #-- Not sure if I need these two
 		self.error_dialog = None  #-- lines...
@@ -261,7 +263,8 @@ class rdesktop:
         def change_exp(self, widget) :
                 #Called when an experience box is toggled
                 #To avoid confusion, this should change the experience combo to "Custom"
-                self.cmb_exp_preset.set_active(4)
+                if self.changing_preset == False :
+                        self.cmb_exp_preset.set_active(4)
         
         def reset_exp_checks(self) :
                 self.chk_exp_desktop.set_active(False)
@@ -275,6 +278,7 @@ class rdesktop:
         def exp_preset_change(self, widget) : #If we change the presets, update the checkboxes
                 #I was smart when writing this function, to avoid rewriting code
                 #The presets just add on themselves going up...
+                self.changing_preset = True
                 self.reset_exp_checks()
                 if self.cmb_exp_preset.get_active() >= 0 :
                         self.chk_exp_bitmap.set_active(True)
@@ -291,6 +295,7 @@ class rdesktop:
                 #        self.reset_exp_checks()
                 #At first, I thought selecting "Custom" should clear the checkboxes...
                 #  I changed my mind...
+                self.changing_preset = False
 
 	def ok_advanced(self, widget) :
 		self.dlg_advanced.hide()
